@@ -80,28 +80,27 @@ def init_regions_for(args):
 
     return init_regions, None
 
+def override_vals(to_override, new_vals):
+    if new_vals is None:
+        return
+    for idx, new_val in enumerate(new_vals):
+        if new_val is not None:
+            to_override[idx] = new_val
+
 def damon_intervals_for(args):
-    default_intervals = _damon.DamonIntervals()
+    intervals = ['5ms', '100ms', '1s']
+    override_vals(intervals, args.monitoring_intervals)
+    override_vals(intervals, [args.sample, args.aggr, args.updr])
+
     intervals_goal = _damon.DamonIntervalsGoal(*args.monitoring_intervals_goal)
-    intervals1 = _damon.DamonIntervals(args.sample, args.aggr, args.updr,
-                                       intervals_goal)
-    intervals2 = _damon.DamonIntervals(*args.monitoring_intervals,
-                                       intervals_goal)
-    if not intervals1 == default_intervals:
-        return intervals1
-    if not intervals2 == default_intervals:
-        return intervals2
-    return default_intervals
+
+    return _damon.DamonIntervals(*intervals, intervals_goal)
 
 def damon_nr_regions_range_for(args):
-    default_range = _damon.DamonNrRegionsRange()
-    range1 = _damon.DamonNrRegionsRange(args.minr, args.maxr)
-    range2 = _damon.DamonNrRegionsRange(*args.monitoring_nr_regions_range)
-    if not range1 == default_range:
-        return range1
-    if not range2 == default_range:
-        return range2
-    return default_range
+    nr_range = ['10', '1000']
+    override_vals(nr_range, args.monitoring_nr_regions_range)
+    override_vals(nr_range, [args.minr, args.maxr])
+    return _damon.DamonNrRegionsRange(*nr_range)
 
 def schemes_option_to_damos(schemes):
     if os.path.isfile(schemes):
@@ -172,7 +171,7 @@ def damos_options_to_filter_v2(words):
     ftype = words[nr_consumed_words]
     nr_consumed_words += 1
 
-    if ftype in ['anon', 'young', 'unmapped']:
+    if ftype in ['anon', 'active', 'young', 'unmapped']:
         filter = _damon.DamosFilter(ftype, fmatching, allow=allow)
         return filter, None, nr_consumed_words
     else:
@@ -331,32 +330,6 @@ def damos_options_to_scheme(sz_region, access_rate, age, action,
     except Exception as e:
         return None, 'Wrong \'--damos_*\' argument (%s)' % e
 
-def convert_add_damos_filter_out_args_to_damos_filter_args(args):
-    '''
-    Convert --damos_filter_out arguments to --damos_filter arguments form, and
-    append to --damos_filter so that existing --damos_filter handling code can
-    just reused.
-
-    --damos_filter_out receives three arguments: type, matching, and optional
-    arguments for the type of filter (memcg path for memcg type).  Those are
-    same to --damos_filter, but 'matching' is optional.  The default value is
-    'matching'.
-    '''
-    for filter_out_args in args.damos_filter_out:
-        if len(filter_out_args) < 1:
-            return '--damos_filter_out with no argument'
-        if filter_out_args[0] == 'not':
-            fmatching = 'nomatching'
-            filter_out_args = filter_out_args[1:]
-            if len(filter_out_args) < 1:
-                return 'filter type not given'
-        else:
-            fmatching = 'matching'
-        ftype = filter_out_args[0]
-        ftype_args = filter_out_args[1:]
-        args.damos_filter.append([ftype, fmatching] + ftype_args)
-    return None
-
 def damos_options_to_schemes(args):
     if args.damos_quota_interval:
         for i, interval in enumerate(args.damos_quota_interval):
@@ -390,10 +363,6 @@ def damos_options_to_schemes(args):
         return [], 'wrong --damos_nr_quota_goals'
     if len(args.damos_wmarks) > nr_schemes:
         return [], 'too much --damos_wmarks'
-    if len(args.damos_filter_out) > 0:
-        err = convert_add_damos_filter_out_args_to_damos_filter_args(args)
-        if err is not None:
-            return [], 'converting damos_filter_out failed (%s)' % err
     # for multiple schemes, number of filters per scheme is required
     if len(args.damos_filter) > 0 and nr_schemes > 1:
         if len(args.damos_nr_filters) == 0:
@@ -676,29 +645,28 @@ def set_monitoring_attrs_pinpoint_argparser(parser, hide_help=False):
     # for easier pinpoint setup
     parser.add_argument(
             '-s', '--sample', metavar='<microseconds>',
-            default=5000, help='sampling interval (us)'
+            help='sampling interval (us)'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '-a', '--aggr', metavar='<microseconds>',
-            default=100000, help='aggregate interval (us)'
+            help='aggregate interval (us)'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '-u', '--updr', metavar='<microseconds>',
-            default=1000000, help='regions update interval (us)'
+            help='regions update interval (us)'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '-n', '--minr', metavar='<# regions>',
-            default=10, help='minimal number of regions'
+            help='minimal number of regions'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '-m', '--maxr', metavar='<# regions>',
-            default=1000, help='maximum number of regions'
+            help='maximum number of regions'
             if not hide_help else argparse.SUPPRESS)
 
 def set_monitoring_attrs_argparser(parser, hide_help=False):
     # for easier total setup
     parser.add_argument('--monitoring_intervals', nargs=3,
-                        default=['5ms', '100ms', '1s'],
                         metavar=('<sample>', '<aggr>', '<update>'),
                         help='monitoring intervals (us)'
                         if not hide_help else argparse.SUPPRESS)
@@ -709,7 +677,7 @@ def set_monitoring_attrs_argparser(parser, hide_help=False):
             help='monitoring intervals auto-tuning goal'
             if not hide_help else argparse.SUPPRESS)
     parser.add_argument('--monitoring_nr_regions_range', nargs=2,
-                        metavar=('<min>', '<max>'), default=[10, 1000],
+                        metavar=('<min>', '<max>'),
                         help='min/max number of monitoring regions'
                         if not hide_help else argparse.SUPPRESS)
 
@@ -795,6 +763,16 @@ def set_damos_argparser(parser, hide_help):
             default=[], metavar='<integer>',
             help='number of quota goals for each scheme (in order)'
             if not hide_help else argparse.SUPPRESS)
+    parser.add_argument(
+            '--damos_filter', nargs='+', action='append',
+            default=[],
+            metavar='<<allow|reject> [none] <type> [option]...>',
+            help='damos filter' if not hide_help else argparse.SUPPRESS)
+    parser.add_argument(
+            '--damos_nr_filters', type=int, nargs='+', default=[],
+            metavar='<integer>',
+            help='number of filters for each scheme (in order)'
+            if not hide_help else argparse.SUPPRESS)
     parser.add_argument(
             '--damos_wmarks', nargs=5, action='append', default=[],
             metavar=('<metric (none|free_mem_rate)>', '<interval (us)>',
@@ -802,27 +780,8 @@ def set_damos_argparser(parser, hide_help):
                 '<low mark (permil)>'),
             help='damos watermarks'
             if not hide_help else argparse.SUPPRESS)
-    parser.add_argument(
-            '--damos_filter', nargs='+', action='append',
-            default=[],
-            metavar='<<allow|reject> [none] <type> [option]...>',
-            help='damos filter' if not hide_help else argparse.SUPPRESS)
-    parser.add_argument(
-            '--damos_filter_out', nargs='+', action='append',
-            default=[],
-            metavar='<filter argument>',
-            help=argparse.SUPPRESS)
-            # help='damos filter (matching, type, and optional arguments)'
-            # if not hide_help else argparse.SUPPRESS)
-    parser.add_argument(
-            '--damos_nr_filters', type=int, nargs='+', default=[],
-            metavar='<integer>',
-            help='number of filters for each scheme (in order)'
-            if not hide_help else argparse.SUPPRESS)
 
-def set_damon_params_argparser(parser, min_help):
-    set_monitoring_argparser(parser, min_help)
-    set_damos_argparser(parser, min_help)
+def set_misc_damon_params_argparser(parser):
     parser.add_argument('-c', '--schemes', metavar='<json string or file>',
 	    help='data access monitoring-based operation schemes')
     parser.add_argument('--kdamonds', metavar='<json/yaml string or file>',
@@ -836,6 +795,11 @@ def set_damon_params_argparser(parser, min_help):
                 'The implicit monitoring requests.',
                 'It could be a command, process id, special keywords, or full',
                 'DAMON parameters (same to that for --kdamonds)']))
+
+def set_damon_params_argparser(parser, min_help):
+    set_monitoring_argparser(parser, min_help)
+    set_damos_argparser(parser, min_help)
+    set_misc_damon_params_argparser(parser)
     set_monitoring_attrs_pinpoint_argparser(parser, hide_help=True)
 
 def set_argparser(parser, add_record_options, min_help):
@@ -848,5 +812,5 @@ def set_argparser(parser, add_record_options, min_help):
         if parser.epilog is None:
             parser.epilog = ''
         parser.epilog += ' '.join([
-            "DAMON parameters options from 'damo args damon' are also",
-            "supported. Do 'damo args damon -h' for the options."])
+            "DAMON parameters options are also supported.",
+            "Do 'damo help damon_param_options -h' for the options."])
